<%inherit file="/layout.html"/>
<%block name="title">list</%block>

<h1>List</h1>
<%include file="/common/list.html" args="object_list=current_page.object_list, path=request.path"/>
<div>
    <div class="commands" style="float:right;">
        <a href="${request.path}/new" class="btn btn-primary">New</a>
    </div>
    <%include file="/common/paginator.html" args="page_obj=current_page, page_number=page"/>
</div>