from setuptools import setup
setup(name='djangobp',
      version='1.0',
      packages=['djangobp', 
                'djangobp.management', 
                'djangobp.management.commands', 
                'djangobp.scaffold',
                'djangobp.scaffold.app',
                'djangobp.scaffold.app.controllers',
                'djangobp.scaffold.app.static',
                'djangobp.scaffold.app.templates',
                'djangobp.scaffold.model',
                'djangobp.scaffold.model.controllers',
                'djangobp.scaffold.model.templates',
                'djangobp.scaffold.scaffold',
                'djangobp.scaffold.socialauth',
                'djangobp.scaffold.socialauth.controllers',
                'djangobp.scaffold.socialauth.templates',
                ],
      package_data={'djangobp.scaffold.app.static': ['css/*', 'js/*', 'images/*', 'fancybox/*'],
                    'djangobp.scaffold.app.templates': ['*'],
                    'djangobp.scaffold.model.templates': ['common/*', 'sample/*'],
                    'djangobp.scaffold.socialauth.templates': ['accounts/*'],
                    },
      scripts=['scripts/djangobp-install.py']
      )
